pytilities.overloading.matchers

Package pytilities :: Package overloading :: Module matchers |
[hide private]
[frames] | no frames]

# Module matchers

source code

Functions | [hide private]
matches_everything(value) A matcher that always returns true | source code
matches_type(*types) A matcher that matches values which are instances of any of given types types: -- collection of types | source code
matches_all(*matchers) A matcher that matches values which match all given matchers matchers: -- collection of matcher functions | source code
matches_any(*matchers) A matcher that matches values which are instances of any of given types matchers: -- ordered sequence of matcher functions | source code
matches_none(*matchers) A matcher that matches values which are instances of any of given types matchers: -- collection of matcher functions | source code

Variables | [hide private]
| __package__ = `None`